@@ -1,9 +1,9 @@
 package Data::CSel;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-04-07'; # DATE
+our $DATE = '2020-04-09'; # DATE
 our $DIST = 'Data-CSel'; # DIST
-our $VERSION = '0.122'; # VERSION
+our $VERSION = '0.123'; # VERSION
 
 use 5.020000;
 use strict;
@@ -16,6 +16,7 @@ use Scalar::Util qw(blessed refaddr looks_like_number);
 use Exporter qw(import);
 our @EXPORT_OK = qw(
                        csel
+                       csel_each
                        parse_csel
                );
 
@@ -709,6 +710,15 @@ sub csel {
     }
 }
 
+sub csel_each(&;@) {
+    my $cb = shift;
+    for my $node (csel(@_)) {
+        local $_ = $node;
+        $cb->($_);
+    }
+    undef;
+}
+
 1;
 # ABSTRACT: Select tree node objects using CSS Selector-like syntax
 
@@ -724,13 +734,18 @@ Data::CSel - Select tree node objects using CSS Selector-like syntax
 
 =head1 VERSION
 
-This document describes version 0.122 of Data::CSel (from Perl distribution Data-CSel), released on 2020-04-07.
+This document describes version 0.123 of Data::CSel (from Perl distribution Data-CSel), released on 2020-04-09.
 
 =head1 SYNOPSIS
 
- use Data::CSel qw(csel);
+ use Data::CSel qw(csel csel_each);
 
  my @cells = csel("Table[name=~/data/i] TCell[value != '']:first", $tree);
+ for (@cells) { say $_->value }
+
+Using L</csel_each>:
+
+Using selection object:
 
  # ditto, but wrap result using a Data::CSel::Selection
  my $res = csel({wrap=>1}, "Table ...", $tree);
@@ -1396,6 +1411,21 @@ C<children> to set children nodes.
 
 =back
 
+=head2 csel_each
+
+Usage:
+
+ csel_each { say $_[0]->value } "expr", $tree;
+ csel_each { say $_->value    } {csel_opt1=>..., ...}, "expr", $tree1, $tree2;
+
+Execute callback for every node that matches expression. Basically shortcut for:
+
+ my @nodes = csel(...);
+ for (@nodes) { $callback->($_) )}
+
+The callback will retrieve the node either in the first element of C<@_> or in
+the localized C<$_> for convenience.
+
 =head2 parse_csel
 
 Usage:
